@@ -55,10 +55,10 @@ class powerswitch:
             self.timeout=float(timeout)
         else:
             self.timeout=CONFIG['timeout']
-        if cycle_time:
-            self.cycle_time=float(cycle_time)
+        if cycletime:
+            self.cycletime=float(cycletime)
         else:
-            self.cycle_time=CONFIG['cycletime']
+            self.cycletime=CONFIG['cycletime']
     def load_configuration(self):
         """ Return a configuration dictionary """
         if os.path.isfile(CONFIG_FILE):
@@ -137,7 +137,7 @@ class powerswitch:
         else:
           if self.off(outlet):
             return True
-          time.sleep(CYCLETIME)
+          time.sleep(self.cycletime)
           if self.on(outlet):
             return True
         return self.status(outlet) != start_status
